#!/usr/bin/env node
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT license.
Object.defineProperty(exports, "__esModule", { value: true });
const commander = require("commander");
const office_addin_cli_1 = require("office-addin-cli");
const commands = require("./commands");
commander.name("office-addin-manifest");
commander.version(process.env.npm_package_version || "(version not available)");
commander
    .command("info <manifest-path>")
    .action(commands.info);
commander
    .command("modify <manifest-path>")
    .option("-g,--guid [guid]", "Change the guid. A random guid is used if one is not provided.")
    .option("-d, --displayName <name>", "Change the display name.")
    .action(commands.modify);
commander
    .command("validate <manifest-path>")
    .action(commands.validate);
// if the command is not known, display an error
commander.on("command:*", function () {
    office_addin_cli_1.logErrorMessage(`The command syntax is not valid.\n`);
    process.exitCode = 1;
    commander.help();
});
if (process.argv.length > 2) {
    commander.parse(process.argv);
}
else {
    commander.help();
}
//# sourceMappingURL=cli.js.map